#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINUSONE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINUSONE_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/minusone.hpp>

#endif
